@@ -494,5 +494,46 @@ def clean_path(path):
     return path
 
 
+
+def title_case(value,reverse=False):
+    orig_type = 'list'
+    if isinstance(value,(str)):
+        orig_type = 'string'
+        value = [value]
+    result = []
+    if reverse is True:
+        result = reverse_title_case(value)
+    else:
+        for word in value:
+            result.append(word.title())
+
+    if orig_type == 'list':
+        return result
+    if orig_type == 'string' and len(result) == 1:
+        return result[0]
+    else:
+        return result
+
+def reverse_title_case(value):
+    orig_type = 'list'
+
+    if isinstance(value,(str)):
+        orig_type = 'string'
+        value = [value]
+
+    result = []
+    for word in value:
+        lower = word.lower()
+        upper = word.upper()
+        result.append(f"{lower[0]}{upper[1:]}")
+
+    if orig_type == 'list':
+        return result
+    if orig_type == 'string' and len(result) == 1:
+        return result[0]
+    else:
+        return result
+    
+
 # ----------========== ALIASES ==========----------
 left_pad = leftPad
