@@ -123,7 +123,8 @@ def variations(value,**kwargs):
     
     if isinstance(value,(str)):
         value = [value]
-        
+    
+    result = []
     for term in value:
         # value = str(value)
         varis = []
@@ -134,8 +135,10 @@ def variations(value,**kwargs):
             varis.append(strFormat.to_screaming_snake(term))
             varis.extend(strFormat.title_case(varis))
             varis.extend(strFormat.title_case(varis,True))
-    varis = list(set(varis))
-    return varis
+        if len(varis) > 1:
+            varis = list(set(varis))
+        result.extend(varis)
+    return result
 
 TYPO_PROXIMITY_KEYBOARD = {
         '1': "2q",
@@ -267,5 +270,5 @@ def replace_at(s, newstring, index, nofail=False):
 
 
 
-# print(variations(["colemen","coleman"],case=False))
+print(variations(["abc","123"],case=False))
 # print(missed_key_typos("colemen"))
